"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .usermodel_output import UserModelOutput, UserModelOutputTypedDict
from datetime import datetime
from mixpeek.types import BaseModel
from typing import List, Optional
from typing_extensions import NotRequired, TypedDict


class OrganizationModelMetadataTypedDict(TypedDict):
    pass


class OrganizationModelMetadata(BaseModel):
    pass


class OrganizationModelTypedDict(TypedDict):
    organization_name: str
    organization_id: NotRequired[str]
    internal_id: NotRequired[str]
    created_at: NotRequired[datetime]
    account_type: NotRequired[str]
    credit_count: NotRequired[int]
    metadata: NotRequired[OrganizationModelMetadataTypedDict]
    users: NotRequired[List[UserModelOutputTypedDict]]


class OrganizationModel(BaseModel):
    organization_name: str

    organization_id: Optional[str] = None

    internal_id: Optional[str] = None

    created_at: Optional[datetime] = None

    account_type: Optional[str] = "free"

    credit_count: Optional[int] = 1000

    metadata: Optional[OrganizationModelMetadata] = None

    users: Optional[List[UserModelOutput]] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class TaskStatus(str, Enum):
    DONE = "DONE"
    FAILED = "FAILED"
    SKIPPED = "SKIPPED"
    CANCELLED = "CANCELLED"
    PROCESSING = "PROCESSING"
    DOWNLOADING = "DOWNLOADING"
    INITIALIZING = "INITIALIZING"
    UPLOADING = "UPLOADING"
    QUEUED = "QUEUED"
    PENDING = "PENDING"



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .db_model_paginationresponse import (
    DbModelPaginationResponse,
    DbModelPaginationResponseTypedDict,
)
from .taxonomymodel import TaxonomyModel, TaxonomyModelTypedDict
from mixpeek.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class ListTaxonomiesResponseTypedDict(TypedDict):
    results: List[TaxonomyModelTypedDict]
    r"""List of fully populated taxonomies with nodes"""
    pagination: DbModelPaginationResponseTypedDict


class ListTaxonomiesResponse(BaseModel):
    results: List[TaxonomyModel]
    r"""List of fully populated taxonomies with nodes"""

    pagination: DbModelPaginationResponse



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum
from mixpeek.types import BaseModel
from typing_extensions import TypedDict


class Mode(str, Enum):
    r"""Update mode: 'replace' or 'append'"""

    REPLACE = "replace"
    APPEND = "append"


class AssetUpdateTypedDict(TypedDict):
    asset_id: str
    r"""Unique identifier for the asset to be updated"""
    mode: Mode
    r"""Update mode: 'replace' or 'append'"""


class AssetUpdate(BaseModel):
    asset_id: str
    r"""Unique identifier for the asset to be updated"""

    mode: Mode
    r"""Update mode: 'replace' or 'append'"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .featureoptions import FeatureOptions, FeatureOptionsTypedDict
from .logicaloperator import LogicalOperator, LogicalOperatorTypedDict
from .nodeoptions import NodeOptions, NodeOptionsTypedDict
from .sortoption import SortOption, SortOptionTypedDict
from mixpeek.types import BaseModel, Nullable, OptionalNullable, UNSET, UNSET_SENTINEL
from pydantic import model_serializer
from typing_extensions import NotRequired, TypedDict


class ListClassificationsRequestTypedDict(TypedDict):
    r"""Request model for listing classifications with filters"""

    filters: NotRequired[Nullable[LogicalOperatorTypedDict]]
    r"""Complex nested query filters for classifications"""
    sort: NotRequired[Nullable[SortOptionTypedDict]]
    r"""Sort options for ordering classifications"""
    feature_options: NotRequired[Nullable[FeatureOptionsTypedDict]]
    r"""Controls what feature data to include in the response. Note: Including additional data increases response latency."""
    node_options: NotRequired[Nullable[NodeOptionsTypedDict]]
    r"""Controls what node data to include in the response. Note: Including additional data increases response latency."""


class ListClassificationsRequest(BaseModel):
    r"""Request model for listing classifications with filters"""

    filters: OptionalNullable[LogicalOperator] = UNSET
    r"""Complex nested query filters for classifications"""

    sort: OptionalNullable[SortOption] = UNSET
    r"""Sort options for ordering classifications"""

    feature_options: OptionalNullable[FeatureOptions] = UNSET
    r"""Controls what feature data to include in the response. Note: Including additional data increases response latency."""

    node_options: OptionalNullable[NodeOptions] = UNSET
    r"""Controls what node data to include in the response. Note: Including additional data increases response latency."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["filters", "sort", "feature_options", "node_options"]
        nullable_fields = ["filters", "sort", "feature_options", "node_options"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in self.model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .embeddingrequest import EmbeddingRequest, EmbeddingRequestTypedDict
from .entitysettings import EntitySettings, EntitySettingsTypedDict
from .jsontextoutputsettings import (
    JSONTextOutputSettings,
    JSONTextOutputSettingsTypedDict,
)
from mixpeek.types import BaseModel, Nullable, OptionalNullable, UNSET, UNSET_SENTINEL
from pydantic import model_serializer
from typing import List, Optional
from typing_extensions import NotRequired, TypedDict


class TextSettingsTypedDict(TypedDict):
    embed: NotRequired[List[EmbeddingRequestTypedDict]]
    r"""List of embedding settings for generating multiple embeddings. field_name's provided are how the raw text will be inserted, if not provided, the field_name will be auto-generated.
    Default: [{type: 'text', embedding_model: 'multimodal'}] if none provided.
    """
    json_output: NotRequired[Nullable[JSONTextOutputSettingsTypedDict]]
    r"""Settings for structured JSON output of text analysis."""
    entities: NotRequired[Nullable[EntitySettingsTypedDict]]
    r"""Settings for extracting entities from text content"""


class TextSettings(BaseModel):
    embed: Optional[List[EmbeddingRequest]] = None
    r"""List of embedding settings for generating multiple embeddings. field_name's provided are how the raw text will be inserted, if not provided, the field_name will be auto-generated.
    Default: [{type: 'text', embedding_model: 'multimodal'}] if none provided.
    """

    json_output: OptionalNullable[JSONTextOutputSettings] = UNSET
    r"""Settings for structured JSON output of text analysis."""

    entities: OptionalNullable[EntitySettings] = UNSET
    r"""Settings for extracting entities from text content"""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["embed", "json_output", "entities"]
        nullable_fields = ["json_output", "entities"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in self.model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class VectorType(str, Enum):
    SPARSE = "sparse"
    DENSE = "dense"



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .vectormodel import VectorModel
from mixpeek.types import BaseModel, Nullable, OptionalNullable, UNSET, UNSET_SENTINEL
from pydantic import model_serializer
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class ImageDescribeSettingsJSONOutputTypedDict(TypedDict):
    r"""JSON format for the response"""


class ImageDescribeSettingsJSONOutput(BaseModel):
    r"""JSON format for the response"""


class ImageDescribeSettingsTypedDict(TypedDict):
    prompt: NotRequired[Nullable[str]]
    r"""Prompt for image description"""
    enabled: NotRequired[bool]
    r"""Enable image description"""
    max_length: NotRequired[Nullable[int]]
    r"""Maximum length of the description"""
    json_output: NotRequired[ImageDescribeSettingsJSONOutputTypedDict]
    r"""JSON format for the response"""
    embedding_model: NotRequired[Nullable[VectorModel]]
    r"""Name of the vector model to use for embedding the text output. If embedding_model is duplicated, the vector will be overwritten."""


class ImageDescribeSettings(BaseModel):
    prompt: OptionalNullable[str] = UNSET
    r"""Prompt for image description"""

    enabled: Optional[bool] = True
    r"""Enable image description"""

    max_length: OptionalNullable[int] = UNSET
    r"""Maximum length of the description"""

    json_output: Optional[ImageDescribeSettingsJSONOutput] = None
    r"""JSON format for the response"""

    embedding_model: OptionalNullable[VectorModel] = UNSET
    r"""Name of the vector model to use for embedding the text output. If embedding_model is duplicated, the vector will be overwritten."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = [
            "prompt",
            "enabled",
            "max_length",
            "json_output",
            "embedding_model",
        ]
        nullable_fields = ["prompt", "max_length", "embedding_model"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in self.model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .availablemodels import AvailableModels
from mixpeek.types import BaseModel
from typing import List, Optional
from typing_extensions import NotRequired, TypedDict


class TaxonomyExtractionConfigTypedDict(TypedDict):
    r"""Configuration for taxonomy-based entity extraction during ingestion"""

    taxonomy_ids: List[str]
    r"""List of taxonomy IDs to use for classification"""
    embedding_models: List[AvailableModels]
    r"""Vector indexes to use for classification"""
    confidence_threshold: NotRequired[float]
    r"""Minimum confidence score required for classification"""


class TaxonomyExtractionConfig(BaseModel):
    r"""Configuration for taxonomy-based entity extraction during ingestion"""

    taxonomy_ids: List[str]
    r"""List of taxonomy IDs to use for classification"""

    embedding_models: List[AvailableModels]
    r"""Vector indexes to use for classification"""

    confidence_threshold: Optional[float] = 0.8
    r"""Minimum confidence score required for classification"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from .basesdk import BaseSDK
from .httpclient import AsyncHttpClient, HttpClient
from .sdkconfiguration import SDKConfiguration
from .utils.logger import Logger, get_default_logger
from .utils.retries import RetryConfig
import httpx
from mixpeek import models, utils
from mixpeek._hooks import SDKHooks
from mixpeek.assets import Assets
from mixpeek.collections import Collections
from mixpeek.featureextractors import FeatureExtractors
from mixpeek.features import Features
from mixpeek.health import Health
from mixpeek.ingestassets import IngestAssets
from mixpeek.models import internal
from mixpeek.namespaces import Namespaces
from mixpeek.organizations import Organizations
from mixpeek.tasks import Tasks
from mixpeek.taxonomies import Taxonomies
from mixpeek.taxonomyentities import TaxonomyEntities
from mixpeek.types import OptionalNullable, UNSET
from mixpeek.users import Users
from typing import Any, Callable, Dict, Optional, Union


class Mixpeek(BaseSDK):
    r"""Mixpeek API: This is the Mixpeek API, providing access to various endpoints for data processing and retrieval."""

    health: Health
    organizations: Organizations
    users: Users
    namespaces: Namespaces
    features: Features
    feature_extractors: FeatureExtractors
    ingest_assets: IngestAssets
    taxonomy_entities: TaxonomyEntities
    taxonomies: Taxonomies
    assets: Assets
    collections: Collections
    tasks: Tasks

    def __init__(
        self,
        token: Optional[Union[Optional[str], Callable[[], Optional[str]]]] = None,
        x_namespace: Optional[str] = None,
        server_idx: Optional[int] = None,
        server_url: Optional[str] = None,
        url_params: Optional[Dict[str, str]] = None,
        client: Optional[HttpClient] = None,
        async_client: Optional[AsyncHttpClient] = None,
        retry_config: OptionalNullable[RetryConfig] = UNSET,
        timeout_ms: Optional[int] = None,
        debug_logger: Optional[Logger] = None,
    ) -> None:
        r"""Instantiates the SDK configuring it with the provided parameters.

        :param token: The token required for authentication
        :param x_namespace: Configures the x_namespace parameter for all supported operations
        :param server_idx: The index of the server to use for all methods
        :param server_url: The server URL to use for all methods
        :param url_params: Parameters to optionally template the server URL with
        :param client: The HTTP client to use for all synchronous methods
        :param async_client: The Async HTTP client to use for all asynchronous methods
        :param retry_config: The retry configuration to use for all supported methods
        :param timeout_ms: Optional request timeout applied to each operation in milliseconds
        """
        if client is None:
            client = httpx.Client()

        assert issubclass(
            type(client), HttpClient
        ), "The provided client must implement the HttpClient protocol."

        if async_client is None:
            async_client = httpx.AsyncClient()

        if debug_logger is None:
            debug_logger = get_default_logger()

        assert issubclass(
            type(async_client), AsyncHttpClient
        ), "The provided async_client must implement the AsyncHttpClient protocol."

        security: Any = None
        if callable(token):
            # pylint: disable=unnecessary-lambda-assignment
            security = lambda: models.Security(token=token())
        else:
            security = models.Security(token=token)

        if server_url is not None:
            if url_params is not None:
                server_url = utils.template_url(server_url, url_params)

        _globals = internal.Globals(
            x_namespace=utils.get_global_from_env(
                x_namespace, "MIXPEEK_X_NAMESPACE", str
            ),
        )

        BaseSDK.__init__(
            self,
            SDKConfiguration(
                client=client,
                async_client=async_client,
                globals=_globals,
                security=security,
                server_url=server_url,
                server_idx=server_idx,
                retry_config=retry_config,
                timeout_ms=timeout_ms,
                debug_logger=debug_logger,
            ),
        )

        hooks = SDKHooks()

        current_server_url, *_ = self.sdk_configuration.get_server_details()
        server_url, self.sdk_configuration.client = hooks.sdk_init(
            current_server_url, self.sdk_configuration.client
        )
        if current_server_url != server_url:
            self.sdk_configuration.server_url = server_url

        # pylint: disable=protected-access
        self.sdk_configuration.__dict__["_hooks"] = hooks

        self._init_sdks()

    def _init_sdks(self):
        self.health = Health(self.sdk_configuration)
        self.organizations = Organizations(self.sdk_configuration)
        self.users = Users(self.sdk_configuration)
        self.namespaces = Namespaces(self.sdk_configuration)
        self.features = Features(self.sdk_configuration)
        self.feature_extractors = FeatureExtractors(self.sdk_configuration)
        self.ingest_assets = IngestAssets(self.sdk_configuration)
        self.taxonomy_entities = TaxonomyEntities(self.sdk_configuration)
        self.taxonomies = Taxonomies(self.sdk_configuration)
        self.assets = Assets(self.sdk_configuration)
        self.collections = Collections(self.sdk_configuration)
        self.tasks = Tasks(self.sdk_configuration)

    def __enter__(self):
        return self

    async def __aenter__(self):
        return self

    def __exit__(self, exc_type, exc_val, exc_tb):
        if self.sdk_configuration.client is not None:
            self.sdk_configuration.client.close()

    async def __aexit__(self, exc_type, exc_val, exc_tb):
        if self.sdk_configuration.async_client is not None:
            await self.sdk_configuration.async_client.aclose()



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from mixpeek.types import BaseModel, Nullable, OptionalNullable, UNSET, UNSET_SENTINEL
from mixpeek.utils import FieldMetadata, HeaderMetadata, PathParamMetadata
import pydantic
from pydantic import model_serializer
from typing_extensions import Annotated, NotRequired, TypedDict


class GetCollectionV1CollectionsCollectionGetRequestTypedDict(TypedDict):
    collection: str
    r"""Either the collection name or collection ID"""
    x_namespace: NotRequired[Nullable[str]]
    r"""Optional namespace for data isolation. This can be a namespace name or namespace ID. Example: 'netflix_prod' or 'ns_1234567890'. To create a namespace, use the /namespaces endpoint."""


class GetCollectionV1CollectionsCollectionGetRequest(BaseModel):
    collection: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]
    r"""Either the collection name or collection ID"""

    x_namespace: Annotated[
        OptionalNullable[str],
        pydantic.Field(alias="X-Namespace"),
        FieldMetadata(header=HeaderMetadata(style="simple", explode=False)),
    ] = UNSET
    r"""Optional namespace for data isolation. This can be a namespace name or namespace ID. Example: 'netflix_prod' or 'ns_1234567890'. To create a namespace, use the /namespaces endpoint."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["X-Namespace"]
        nullable_fields = ["X-Namespace"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in self.model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from mixpeek.types import BaseModel
from mixpeek.utils import FieldMetadata, PathParamMetadata
from typing_extensions import Annotated, TypedDict


class DeleteNamespaceV1NamespacesNamespaceDeleteRequestTypedDict(TypedDict):
    namespace: str
    r"""Either the namespace name or namespace ID"""


class DeleteNamespaceV1NamespacesNamespaceDeleteRequest(BaseModel):
    namespace: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]
    r"""Either the namespace name or namespace ID"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

import importlib.metadata

__title__: str = "mixpeek"
__version__: str = "0.18.2"
__openapi_doc_version__: str = "0.81"
__gen_version__: str = "2.493.32"
__user_agent__: str = "speakeasy-sdk/python 0.18.2 2.493.32 0.81 mixpeek"

try:
    if __package__ is not None:
        __version__ = importlib.metadata.version(__package__)
except importlib.metadata.PackageNotFoundError:
    pass



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .actionusage import ActionUsage, ActionUsageTypedDict
from mixpeek.types import BaseModel
import pydantic
from typing import List
from typing_extensions import Annotated, TypedDict


class DateUsageTypedDict(TypedDict):
    date_: str
    credits: int
    actions: List[ActionUsageTypedDict]


class DateUsage(BaseModel):
    date_: Annotated[str, pydantic.Field(alias="date")]

    credits: int

    actions: List[ActionUsage]



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .classificationmatch import ClassificationMatch, ClassificationMatchTypedDict
from .featureresponse import FeatureResponse, FeatureResponseTypedDict
from mixpeek.types import BaseModel, Nullable, OptionalNullable, UNSET, UNSET_SENTINEL
from pydantic import model_serializer
from typing import List
from typing_extensions import NotRequired, TypedDict


class ClassificationWithFeatureTypedDict(TypedDict):
    r"""Classification entry with optional full feature and node data"""

    feature_id: str
    r"""ID of the classified feature"""
    classification_id: str
    r"""ID of the classification run"""
    taxonomy_id: str
    r"""ID of the taxonomy used"""
    matches: List[ClassificationMatchTypedDict]
    r"""List of node matches with scores"""
    feature: NotRequired[Nullable[FeatureResponseTypedDict]]
    r"""Full feature object if requested"""


class ClassificationWithFeature(BaseModel):
    r"""Classification entry with optional full feature and node data"""

    feature_id: str
    r"""ID of the classified feature"""

    classification_id: str
    r"""ID of the classification run"""

    taxonomy_id: str
    r"""ID of the taxonomy used"""

    matches: List[ClassificationMatch]
    r"""List of node matches with scores"""

    feature: OptionalNullable[FeatureResponse] = UNSET
    r"""Full feature object if requested"""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["feature"]
        nullable_fields = ["feature"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in self.model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class InputType(str, Enum):
    URL = "url"
    TEXT = "text"
    FILE = "file"
    BASE64 = "base64"



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from mixpeek.types import BaseModel
from typing_extensions import TypedDict


class FeatureUpdateRequestMetadataTypedDict(TypedDict):
    pass


class FeatureUpdateRequestMetadata(BaseModel):
    pass


class FeatureUpdateRequestTypedDict(TypedDict):
    metadata: FeatureUpdateRequestMetadataTypedDict


class FeatureUpdateRequest(BaseModel):
    metadata: FeatureUpdateRequestMetadata



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .apikeyupdate import APIKeyUpdate, APIKeyUpdateTypedDict
from mixpeek.types import BaseModel
from mixpeek.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing_extensions import Annotated, TypedDict


class UpdateAPIKeyV1OrganizationsUsersUserEmailAPIKeysKeyNamePatchRequestTypedDict(
    TypedDict
):
    user_email: str
    key_name: str
    api_key_update: APIKeyUpdateTypedDict


class UpdateAPIKeyV1OrganizationsUsersUserEmailAPIKeysKeyNamePatchRequest(BaseModel):
    user_email: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]

    key_name: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]

    api_key_update: Annotated[
        APIKeyUpdate,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .collectionresult import CollectionResult, CollectionResultTypedDict
from .db_model_paginationresponse import (
    DbModelPaginationResponse,
    DbModelPaginationResponseTypedDict,
)
from mixpeek.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class ListCollectionsResponseTypedDict(TypedDict):
    results: List[CollectionResultTypedDict]
    pagination: DbModelPaginationResponseTypedDict


class ListCollectionsResponse(BaseModel):
    results: List[CollectionResult]

    pagination: DbModelPaginationResponse



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum
from mixpeek.types import BaseModel
from typing_extensions import TypedDict


class Direction(str, Enum):
    r"""Sort direction"""

    ASC = "asc"
    DESC = "desc"


class SortOptionTypedDict(TypedDict):
    field: str
    r"""Field to sort by, supports dot notation for nested fields"""
    direction: Direction
    r"""Sort direction"""


class SortOption(BaseModel):
    field: str
    r"""Field to sort by, supports dot notation for nested fields"""

    direction: Direction
    r"""Sort direction"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .updatenamespacerequest import (
    UpdateNamespaceRequest,
    UpdateNamespaceRequestTypedDict,
)
from mixpeek.types import BaseModel
from mixpeek.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing_extensions import Annotated, TypedDict


class UpdateNamespaceV1NamespacesNamespacePutRequestTypedDict(TypedDict):
    namespace: str
    r"""Either the namespace name or namespace ID"""
    update_namespace_request: UpdateNamespaceRequestTypedDict


class UpdateNamespaceV1NamespacesNamespacePutRequest(BaseModel):
    namespace: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]
    r"""Either the namespace name or namespace ID"""

    update_namespace_request: Annotated[
        UpdateNamespaceRequest,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .permission import Permission
from datetime import datetime
from mixpeek.types import BaseModel
from typing import List, Optional
from typing_extensions import NotRequired, TypedDict


class APIKeyTypedDict(TypedDict):
    key: NotRequired[str]
    name: NotRequired[str]
    created_at: NotRequired[datetime]
    permissions: NotRequired[List[Permission]]


class APIKey(BaseModel):
    key: Optional[str] = None

    name: Optional[str] = None

    created_at: Optional[datetime] = None

    permissions: Optional[List[Permission]] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .errordetail import ErrorDetail
from mixpeek import utils
from mixpeek.types import BaseModel
from typing import Optional


class ErrorResponseData(BaseModel):
    status: int

    error: ErrorDetail

    success: Optional[bool] = False


class ErrorResponse(Exception):
    data: ErrorResponseData

    def __init__(self, data: ErrorResponseData):
        self.data = data

    def __str__(self) -> str:
        return utils.marshal_json(self.data, ErrorResponseData)
